<p align="center">
    <img width="350" height="150" src="https://cdn.jsdelivr.net/gh/szj2ys/Qomolangma/langma/logo.png"/>
</p>

<h3 align="center">
    <p>Awesome NLP framework you are waiting for ✨</p>
</h3>


<p align="center">
    <a href="https://python.org/pypi/Qomolangma">
        <img src="https://badge.fury.io/py/Qomolangma.svg" alt="Version"/>
    </a>
    <a href="https://python.org/pypi/Qomolangma">
        <img src="https://img.shields.io/pypi/l/Qomolangma.svg?color=orange" alt="License"/>
    </a>
    <a href="https://python.org/pypi/Qomolangma">
        <img src="https://static.pepy.tech/badge/Qomolangma?color=blue" alt="pypi total downloads"/>
    </a>
    <a href="https://python.org/pypi/Qomolangma">
        <img src="https://img.shields.io/github/last-commit/szj2ys/Qomolangma?color=blue" alt="GitHub last commit"/>
    </a>
</p>

`Qomolangma` is the highest mountain on Earth
Snow-capped mountains, azure sky, golden rays of sunshine, the pure and 
mysterious aura of Tibet has excited the imagination of so many people of the world. 

And also in the world of NLP, `Qomolangma` want to be a peak in natural 
language processing

## Installation⚙ 🔑 🎛️ 🙈 🎠 ❌ 🎉 
```shell
pip install langma
```

hahahaha...`Qomolangma` is now on your environment, enjoy...

if you don't know what to do and how, enter `langma -h` for help on 
terminal

## REFERENCES
- [logly](https://www.logoly.pro/)
- [Kashgari](https://github.com/BrikerMan/Kashgari/)


<p align="center">
    <img src="https://cdn.jsdelivr.net/gh/szj2ys/Qomolangma/langma/everest.jpeg"/>
</p>

